==> haskell-th-orphans-0.13.7-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.7
id: th-orphans-0.13.7-3p9top26QmdL7WioCb2df
key: th-orphans-0.13.7-3p9top26QmdL7WioCb2df
license: BSD-3-Clause
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
author: Matt Morrow
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
abi: 939ed0b90f2d4192197c2fd99a102b19
exposed: True
exposed-modules:
    Language.Haskell.TH.Instances
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-orphans-0.13.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-orphans-0.13.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-orphans-0.13.7
hs-libraries: HSth-orphans-0.13.7-3p9top26QmdL7WioCb2df
depends:
    base-4.12.0.0 mtl-2.2.2 template-haskell-2.14.0.0
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-reify-many-0.1.9-AO2I3KZjoiS9IDtUI7zilG
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.7-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.7
id: th-orphans-0.13.7-HghHJKVho5DVkBF1DPzmR
key: th-orphans-0.13.7-HghHJKVho5DVkBF1DPzmR
license: BSD-3-Clause
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
author: Matt Morrow
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
abi: 2bc58d7c059f9443624a5286d458d522
exposed: True
exposed-modules:
    Language.Haskell.TH.Instances
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-orphans-0.13.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-orphans-0.13.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-orphans-0.13.7
hs-libraries: HSth-orphans-0.13.7-HghHJKVho5DVkBF1DPzmR
depends:
    base-4.12.0.0 mtl-2.2.2 template-haskell-2.14.0.0
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-reify-many-0.1.9-G89688xYWjfFURMqNvAi7B
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
